@@ -174,8 +174,22 @@ class Node(object):
     ##|
     ##|  TRAVERSAL
     ##|
+    @property
+    def siblings(self):
+        """
+        Returns a list of siblings.  Does not include the index page of the parent folder.
+        """
+        if not self.parent:
+            return [self]
+
+        return [page for page in self.parent]
+
     @property
     def next(self):
+        """
+        Returns the next node, or None if this is the last node or if this node does not
+        have a parent.
+        """
         if not self.parent:
             return None
 
@@ -186,6 +200,10 @@ class Node(object):
 
     @property
     def prev(self):
+        """
+        Returns the previous node, or None if this is the first node or if this node does not
+        have a parent.
+        """
         if not self.parent:
             return None
 
@@ -197,9 +215,6 @@ class Node(object):
     def __nonzero__(self):
         return True
 
-    def __setitem__(self, key, value):
-        self.config[key] = value
-
     def __getitem__(self, key):
         return self.__getattr__(key)
 
